@@ -83,7 +83,7 @@
 
 #define KEY_INPUT "split_input"
 #define KEY_OUTPUT "split_output"
-#define DAR_SPLIT_VERSION "1.1.2"
+#define DAR_SPLIT_VERSION "1.1.3"
 
 static void usage(char *a);
 static void show_version(char *a);
@@ -231,7 +231,7 @@ static void stop_and_wait()
 
     purge_fd(fd_inter);
     fprintf(stderr, "Press return when ready to continue or hit CTRL-C to abort\n");
-    read(fd_inter, tmp, 3);
+    (void)read(fd_inter, tmp, 3);
 }
 
 static void pipe_handle_pause(int x)
@@ -333,6 +333,8 @@ static void normal_read_to_multiple_write(char *filename, int sync_mode)
 
 		    offset += ecru;
 		    lu -= ecru;
+		    if(step > lu)
+			step = lu;
 		    tape_size += ecru;
 		}
 	    }
