@@ -436,7 +436,7 @@ namespace libdar
 
 		try
 		{
-		    buf_byte_data = decrypt_data(block_num, encrypted_buf, encrypted_buf_data, buf, clear_block_size);
+		    buf_byte_data = decrypt_data(block_num, encrypted_buf, encrypted_buf_data, buf, buf_size);
 		}
 		catch(Erange & e)
 		{
@@ -447,7 +447,7 @@ namespace libdar
 			    remove_trailing_clear_data_from_encrypted_buf(crypt_offset);
 
 				// retrying but without trailing cleared data
-			    buf_byte_data = decrypt_data(block_num, encrypted_buf, encrypted_buf_data, buf, clear_block_size);
+			    buf_byte_data = decrypt_data(block_num, encrypted_buf, encrypted_buf_data, buf, buf_size);
 			}
 			catch(Egeneric & f)
 			{
